diff --git a/templates/base.html b/templates/base.html
index d3f2a37..720c681 100644
--- a/templates/base.html
+++ b/templates/base.html
@@ -11,20 +11,18 @@
href="{{ url_for('static', filename='css/style.css') }}"
/>
-
- {% if THEME_NAME %}
-
- {% endif %}
-
+
+ {% if THEME_NAME %}
+
+ {% endif %}
+
{% block extra_head %}{% endblock %}
@@ -67,7 +65,7 @@
diff --git a/app.py b/app.py
index ce66588..4c08359 100644
--- a/app.py
+++ b/app.py
@@ -107,8 +107,11 @@ def create_app() -> Flask:
@app.context_processor
def inject_company_name():
- """Make COMPANY_NAME available to all templates"""
- return {'COMPANY_NAME': os.environ.get('COMPANY_NAME', 'QR Code Management System')}
+ """Make COMPANY_NAME and THEME_NAME available to all templates"""
+ return {
+ 'COMPANY_NAME': os.environ.get('COMPANY_NAME', 'QR Code Management System'),
+ 'THEME_NAME': os.environ.get('THEME_NAME', ''),
+ }
@app.context_processor
def inject_logging_status():